/*=========================================================================

  Program:   Visualization Toolkit
  Module:    $RCSfile: vtkPointNormalColorReader.h,v $

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkPointNormalColorReader - read ASCII files in the form
// x y z nx ny nz r g b
// .SECTION Description
// vtkPointNormalColorReader is a source object that reads ASCII files
// of points, normals, and colors. The colors must be unsigned chars.
// The output of this source object is polygonal data.

#ifndef __vtkPointNormalColorReader_h
#define __vtkPointNormalColorReader_h

#include "vtkPolyDataAlgorithm.h"

class VTK_IO_EXPORT vtkPointNormalColorReader : public vtkPolyDataAlgorithm 
{
public:
  static vtkPointNormalColorReader *New();
  vtkTypeRevisionMacro(vtkPointNormalColorReader,vtkPolyDataAlgorithm);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Specify file name of file.
  vtkSetStringMacro(FileName);
  
  // Description:
  // Get the name of the file that was specified.
  vtkGetStringMacro(FileName);

protected:
  vtkPointNormalColorReader();
  ~vtkPointNormalColorReader();
  
  int RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector *);

  char *FileName;
private:
  vtkPointNormalColorReader(const vtkPointNormalColorReader&);  // Not implemented.
  void operator=(const vtkPointNormalColorReader&);  // Not implemented.
};

#endif
